#!/usr/bin/python3
#
# NAME: run_test_install.py
#
# PURPOSE: Performs test on model installation by comparing model output with expected output.
#
# INPUT DATA:
#             SM_tseries.txt -> soil moisture input file
#             ST_tseries.txt -> soil temperature input file
#
# OUTPUT DATA:
#              Part 1 output provided to standard output
#              verify_model_parameters_result.txt  -> Verifies  model parameter statistics are correct
#
# ROUTINES:
#
#          PART 1: VERIFY Z-SCORE INPUT DATA:
#              compute_mean_annual_cycle.py -> Reads soil moisture and temperature training data
#                                              and generates soil moisture and temperature means
#                                              and annual cycle data
#              compute_anomaly_zscores_residuals.py -> Generates soil moisture and temperature z-score
#                                                      data than can be used to train LIM
#              verify_zscores.py -> Determines if zscore input data for the model is computed accurately
#
#
#          PART 2: VERIFY MODEL PARAMETERS:
#              train_lim.py -> Computes LIM parameters neeed to run the LIM forecast model
#              optimal_structure.py -> Determines soil moisture pattern that can provide most skillful
#                                      forecast
#              error_analysis.py -> Defines which method (Correlation or Projection) has the least amount
#                                   of forecast error for determining Forecasts of Opportunity
#
# NOTES:
#          Compare standard output from this program with
#          ../data/verify_model_data/Part1_Part2_output_master.txt
#
# CREATION HISTORY:  Darren Jackson, CIRES/ESRL/PSL, April 2022

import os

#######################################################
# Copy test case soil moisture and temperature data
# into training data directory
########################################################

os.system("cp ./data/verify_data/*.txt ./data/training_data")

###############################################################################
# PART 1:
# These routines will convert the supplied SM and ST time series data into
# z-scores and compare z-score data file with provided in verification run
###############################################################################

os.chdir("./source_v1.2")
os.system("python compute_mean_annual_cycle.py")
os.system("python compute_anomaly_zscores_residuals.py")
os.system("python verify_zscores.py")

######################################################################
# PART 2:
# Output model parameters and compare with reference run of model
######################################################################
os.system("python train_lim.py")
os.system("python optimal_structure.py")
os.system("python error_analysis.py")

